@@ -1,18 +1,21 @@
 import logging
 import logging.handlers
 
-console = False
-log_filename = '/tmp/unset.log'
 formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
-
-fileHandler = logging.handlers.RotatingFileHandler(log_filename, maxBytes=1000000, backupCount=5)
-fileHandler.setFormatter(formatter)
+fileHandler = None
 level = logging.INFO
 
+console = False
 consoleHandler = logging.StreamHandler()
 consoleHandler.setFormatter(formatter)
 
 
+def init(filename):
+    global fileHandler
+    fileHandler = logging.handlers.RotatingFileHandler(filename, maxBytes=1000000, backupCount=5)
+    fileHandler.setFormatter(formatter)
+
+
 def get_logger(name):
     logger = logging.getLogger(name)
     logger.setLevel(level)
@@ -20,3 +23,5 @@ def get_logger(name):
     if console:
         logger.addHandler(consoleHandler)
     return logger
+
+init('/tmp/unset.log')
